@@ -573,7 +573,7 @@ get_changed_tasks (ECalBackendExchange *cbex)
 	E2kResult *result;
 	E2kContext *ctx;
 	const char *modtime, *str, *prop;
-	char *uid, *body;
+	char *uid;
 	char *tzid;
 	int status, i, priority, percent;
 	float f_percent;
@@ -830,8 +830,11 @@ get_changed_tasks (ECalBackendExchange *cbex)
 					modtime, icalcomp);
 			e_cal_backend_exchange_cache_unlock (cbex);
 
-			if (status && kind == ICAL_VTODO_COMPONENT)
-				e_cal_backend_notify_object_created (E_CAL_BACKEND (cbex), icalcomponent_as_ical_string (icalcomp));
+			if (status && kind == ICAL_VTODO_COMPONENT) {
+				char *str = icalcomponent_as_ical_string (icalcomp);
+				e_cal_backend_notify_object_created (E_CAL_BACKEND (cbex), str);
+				g_free (str);
+			}
 
 		}
 	} /* End while */
@@ -923,17 +926,17 @@ get_changed_tasks (ECalBackendExchange *cbex)
 	}
 
 	for (i = 0; i < hrefs->len; i++) {
-		int length;
+		SoupBuffer *response;
 
 		status = e2k_context_get (ctx, NULL, hrefs->pdata[i],
-					NULL, &body, &length);
+					  NULL, &response);
 		if (!SOUP_STATUS_IS_SUCCESSFUL (status))
 			continue;
 		uid = g_hash_table_lookup (attachments, hrefs->pdata[i]);
 		e_cal_backend_exchange_cache_lock (cbex);
 		/* Fetch component from cache and update it */
 		ecalbexcomp = get_exchange_comp (cbex, uid);
-		attachment_list = get_attachment (cbex, uid, body, length);
+		attachment_list = get_attachment (cbex, uid, response->data, response->length);
 		if (attachment_list) {
 			ecomp = e_cal_component_new ();
 			e_cal_component_set_icalcomponent (ecomp, icalcomponent_new_clone (ecalbexcomp->icomp));
@@ -945,7 +948,7 @@ get_changed_tasks (ECalBackendExchange *cbex)
 			g_slist_free (attachment_list);
 		}
 		e_cal_backend_exchange_cache_unlock (cbex);
-		g_free (body);
+		soup_buffer_free (response);
 	}
 
 	for (i = 0; i < hrefs->len; i++)
@@ -1362,10 +1365,13 @@ receive_task_objects (ECalBackendSync *backend, EDataCal *cal,
 			e_cal_backend_exchange_cache_unlock (cbex);
 			calobj = (char *) icalcomponent_as_ical_string (subcomp);
 			status = create_task_object (backend, cal, &calobj, &returned_uid);
-                        if (status != GNOME_Evolution_Calendar_Success)
+                        if (status != GNOME_Evolution_Calendar_Success) {
+				g_free (calobj);
                                 goto error;
+			}
 
                         e_cal_backend_notify_object_created (E_CAL_BACKEND (backend), calobj);
+			g_free (calobj);
                 }
         }
 
